summaryrefslogtreecommitdiff
path: root/Build
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2013-09-21 21:51:26 +0000
committerKarl Berry <karl@freefriends.org>2013-09-21 21:51:26 +0000
commitc1c7638190760c54cc4aa61958a8b0636ad6a968 (patch)
treecabfb00c15b57f6b263ea59195492ab5da7fa706 /Build
parent304ffa799198faa14a701a1676e6d1b00240a194 (diff)
sync
git-svn-id: svn://tug.org/texlive/trunk@31720 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build')
-rw-r--r--Build/source/texk/tests/TeXLive/TLUtils.pm4
-rwxr-xr-xBuild/source/texk/texlive/linked_scripts/texlive/tlmgr.pl16
-rwxr-xr-xBuild/source/texk/texlive/w32_wrapper/runscript.tlu14
3 files changed, 18 insertions, 16 deletions
diff --git a/Build/source/texk/tests/TeXLive/TLUtils.pm b/Build/source/texk/tests/TeXLive/TLUtils.pm
index 3e87f9d56d4..e440b0e1020 100644
--- a/Build/source/texk/tests/TeXLive/TLUtils.pm
+++ b/Build/source/texk/tests/TeXLive/TLUtils.pm
@@ -5,7 +5,7 @@
package TeXLive::TLUtils;
-my $svnrev = '$Revision: 31259 $';
+my $svnrev = '$Revision: 31511 $';
my $_modulerevision;
if ($svnrev =~ m/: ([0-9]+) /) {
$_modulerevision = $1;
@@ -298,7 +298,7 @@ sub platform_name {
chomp (my $sw_vers = `sw_vers -productVersion`);
my ($os_major,$os_minor) = split (/\./, $sw_vers);
#
- chomp (my $sysctl = `sysctl hw.cpu64bit_capable`);
+ chomp (my $sysctl = `PATH=/usr/sbin:\$PATH sysctl hw.cpu64bit_capable`);
my (undef,$hw_64_bit) = split (" ", $sysctl);
#
$CPU = ($os_major >= 10 && $os_minor >= 6 && $hw_64_bit >= 1)
diff --git a/Build/source/texk/texlive/w32_wrapper/runscript.tlu b/Build/source/texk/texlive/w32_wrapper/runscript.tlu
index 9ca13258b09..c519f8f8c4e 100755
--- a/Build/source/texk/texlive/w32_wrapper/runscript.tlu
+++ b/Build/source/texk/texlive/w32_wrapper/runscript.tlu
@@ -1,7 +1,7 @@
-local svnrevision = string.match("$Revision: 31383 $", "%d+") or "0"
-local svndate = string.match("$Date: 2013-08-08 07:15:07 +0200 (Thu, 08 Aug 2013) $", "[-%d]+") or "2009-12-04"
+local svnrevision = string.match("$Revision: 31539 $", "%d+") or "0"
+local svndate = string.match("$Date: 2013-08-30 03:28:47 +0200 (Fri, 30 Aug 2013) $", "[-%d]+") or "2009-12-04"
local bannerstr = "runscript wrapper utility (rev. " ..
svnrevision .. ", " .. svndate .. ")\n" ..
"usage: runscript script-name [arguments]\n" ..
@@ -239,6 +239,9 @@ local docstr = [[
2013/08/08
- allow overriding gs/gs_dll/gs_lib with kpse variables
TEXLIVE_WINDOWS_EXTERNAL_GS, ..._GS_LIB, ..._GS_DLL
+ 2013/08/30
+ - do not pass -NULL to dviout, to allow users changing and
+ saving settings. Patch by Yusuke KUROKI
]]
-- HELPER SUBROUTINES --
@@ -580,10 +583,9 @@ elseif progname == 'dviout' then
table.insert(texrt, d)
end
end
- local par = [[-NULL -dpi=600 "-gen=']] .. string.gsub(TEXDIR, '/', '\\') ..
- [[\tlpkg\dviout\gen_pk'" "-TEXPK=^r\pk\\^s.^dpk;^r\tfm\\^s^tfm;]] ..
- [[^r\vf\\^s.vf;^r\ovf\\^s.ovf;^r\tfm\\^s.tfm" "-TEXROOT=']] ..
- table.concat(texrt, ';') .. [['"]]
+ local par = [["-gen=']] .. string.gsub(TEXDIR, '/', '\\') ..
+ [[\tlpkg\dviout\gen_pk'" "-TEXROOT=']] ..
+ table.concat(texrt, ';') .. [['" "-gsx=']] .. GSEXE .. [['"]];
ARGV = {[0]=TEXDIR..'/tlpkg/dviout/dviout.exe', 'dviout', par}
elseif progname == 'fmtutil' and sysprog then
ARGV = {[0]=BINDIR..'/fmtutil.exe', 'fmtutil', argline}
diff --git a/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl b/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
index 096e7273b45..5e17eac8fa0 100755
--- a/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
+++ b/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
@@ -1,12 +1,12 @@
#!/usr/bin/env perl
-# $Id: tlmgr.pl 31400 2013-08-09 17:49:32Z karl $
+# $Id: tlmgr.pl 31688 2013-09-18 01:18:34Z preining $
#
# Copyright 2008-2013 Norbert Preining
# This file is licensed under the GNU General Public License version 2
# or any later version.
-my $svnrev = '$Revision: 31400 $';
-my $datrev = '$Date: 2013-08-09 19:49:32 +0200 (Fri, 09 Aug 2013) $';
+my $svnrev = '$Revision: 31688 $';
+my $datrev = '$Date: 2013-09-18 03:18:34 +0200 (Wed, 18 Sep 2013) $';
my $tlmgrrevision;
my $prg;
if ($svnrev =~ m/: ([0-9]+) /) {
@@ -4004,8 +4004,8 @@ sub action_option {
}
}
} else {
- if ($what eq "location") {
- # rewrite location -> repository
+ if ($what eq "location" || $what eq "repo") {
+ # silently rewrite location|repo -> repository
$what = "repository";
}
my $found = 0;
@@ -4346,7 +4346,7 @@ sub action_generate {
if ($opts{"rebuild-sys"}) {
do_cmd_and_check("fmtutil-sys --byhyphen \"$dest\"");
} else {
- info("To make the newly-generated language.dat take effect,"
+ info("To make the newly-generated language.dat.lua take effect,"
. " run fmtutil-sys --byhyphen $dest.\n");
}
}
@@ -4724,8 +4724,8 @@ sub check_files {
texmf-dist/ls-R$ texmf-doc/ls-R$
tlpkg/archive tlpkg/backups tlpkg/installer
tlpkg/texlive.tlpdb tlpkg/tlpobj tlpkg/texlive.profile
- texmf-var/ texmf-config/
- texmf.cnf install-tl.log
+ texmf-config/ texmf-var/
+ texmf.cnf texmfcnf.lua install-tl.log
!;
my %tltreefiles = %{$tltree->{'_allfiles'}};
my @tlpdbfiles = keys %filetopacks;